yt.utilities.lib.bounding\_volume\_hierarchy module
===================================================

.. automodule:: yt.utilities.lib.bounding_volume_hierarchy
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
